@@ -5,6 +5,7 @@ import (
 	"bytes"
 	"errors"
 	"io"
+	"regexp"
 	"strings"
 
 	yaml "gopkg.in/yaml.v3"
@@ -40,6 +41,8 @@ func (ye *yamlEncoder) PrintDocumentSeparator(writer io.Writer) error {
 func (ye *yamlEncoder) PrintLeadingContent(writer io.Writer, content string) error {
 	reader := bufio.NewReader(strings.NewReader(content))
 
+	var commentLineRegEx = regexp.MustCompile(`^\s*#`)
+
 	for {
 
 		readline, errReading := reader.ReadString('\n')
@@ -53,6 +56,9 @@ func (ye *yamlEncoder) PrintLeadingContent(writer io.Writer, content string) err
 			}
 
 		} else {
+			if len(readline) > 0 && readline != "\n" && readline[0] != '%' && !commentLineRegEx.MatchString(readline) {
+				readline = "# " + readline
+			}
 			if err := writeString(writer, readline); err != nil {
 				return err
 			}
@@ -72,10 +78,14 @@ func (ye *yamlEncoder) PrintLeadingContent(writer io.Writer, content string) err
 	return nil
 }
 
-func (ye *yamlEncoder) Encode(writer io.Writer, node *yaml.Node) error {
-
-	if node.Kind == yaml.ScalarNode && ye.prefs.UnwrapScalar {
-		return writeString(writer, node.Value+"\n")
+func (ye *yamlEncoder) Encode(writer io.Writer, node *CandidateNode) error {
+	log.Debug("encoderYaml - going to print %v", NodeToString(node))
+	if node.Kind == ScalarNode && ye.prefs.UnwrapScalar {
+		valueToPrint := node.Value
+		if node.LeadingContent == "" || valueToPrint != "" {
+			valueToPrint = valueToPrint + "\n"
+		}
+		return writeString(writer, valueToPrint)
 	}
 
 	destination := writer
@@ -88,7 +98,20 @@ func (ye *yamlEncoder) Encode(writer io.Writer, node *yaml.Node) error {
 
 	encoder.SetIndent(ye.indent)
 
-	if err := encoder.Encode(node); err != nil {
+	target, err := node.MarshalYAML()
+
+	if err != nil {
+		return err
+	}
+
+	trailingContent := target.FootComment
+	target.FootComment = ""
+
+	if err := encoder.Encode(target); err != nil {
+		return err
+	}
+
+	if err := ye.PrintLeadingContent(destination, trailingContent); err != nil {
 		return err
 	}
 
